pub fn seal_with_fsverity(
path: &Path,
algorithm: u32,
) -> Result<(), FsVerityError>Expand description
Seal a file with fs-verity.
The file must not have any open writable file descriptors. After sealing, any modification to the file’s data will cause subsequent reads to return EIO.
Returns Ok(()) on success, or if the file is already sealed (idempotent).